/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

package sync4j.syncclient.spds.event;

/**
 * Is used to notify
 * when a item is added / updated / deleted
 * by a command received from the server
 * or when a item is added / updated / deleted
 * on by the client
 *
 * @author Fabio Maggi
 *
 * @version $Id: SyncItemListener.java,v 1.2 2005/01/19 11:18:36 fabius Exp $
 */
public interface SyncItemListener {

    /**
     * A new item is added on the client
     *
     * @param event
     */
    public void itemAddedByServer(SyncItemEvent event) ;

    /**
     * An item is deleted on the client
     *
     * @param event
     */
    public void itemDeletedByServer(SyncItemEvent event) ;

    /**
     * An item is updated on the client
     *
     * @param event
     */
    public void itemUpdatedByServer(SyncItemEvent event) ;

    /**
     * A new item is added by the client
     *
     * @param event
     */
    public void itemAddedByClient(SyncItemEvent event) ;

    /**
     * An item is deleted by the client
     *
     * @param event
     */
    public void itemDeletedByClient(SyncItemEvent event) ;

    /**
     * An item is updated by the client
     *
     * @param event
     */
    public void itemUpdatedByClient(SyncItemEvent event) ;

}